fn next_index<T: CoordinateType>(
    events: &[Event<T>],
    start_index: usize,
    used: &[bool]
) -> Option<usize>
Given an index of an event get the index of another event with the same coordinates that is not yet marked as used.