struct Event<T: CoordinateType> {
    index: usize,
    other_index: usize,
    prev_index: Option<usize>,
    p: Point<T>,
    is_hole: bool,
    is_upper_boundary: bool,
    is_left_event: bool,
    contour_id: usize,
}

Fields

index: usize

Index of this event in the vector where it is stored.

other_index: usize

Index of the other event of this pair.

prev_index: Option<usize>

The index of the segment just below.

p: Point<T>

The endpoint of the edge which is represented by this event.

is_hole: bool

Is this part of a hole? Used to distinguish between holes and hulls.

is_upper_boundary: bool

Is this an upper boundary of the contour? Used to distinguish between holes and hulls.

is_left_event: bool

Tells if this is the left or right event of the segment.

contour_id: usize