Function iron_shapes_booleanop::sweep_line::compare_segments::compare_edges
source · fn compare_edges<T: CoordinateType>(
first: &Edge<T>,
second: &Edge<T>
) -> OrderingExpand description
Compare two edges.
Returns Less if the starting point of second is below first and Greater if it is above.
If the starting point of second lies on the edge first then the end point is used to break the tie.