pub fn compare_events_by_segments<T, Ctr, P>(
le1: &Rc<SweepEvent<T, Ctr, P>>,
le2: &Rc<SweepEvent<T, Ctr, P>>
) -> Orderingwhere
T: CoordinateType + Debug,Expand description
Compute the ordering of two sweep events. This is used to keep the sweep events sorted in the scan line.
The two sweep events MUST be left events. Otherwise the function panics in debug mode.
Also the two edges defined by the sweep events must overlap when projected on the x-axis. (Otherwise they would not both intersect with the scan line.)
When used correctly the sweep events are sorted by the ascending y-coordinate of their intersection point with the scan line.