fn compare_scanline_elements<T, Ctr, P>(
a: &ScanlineElement<T, Ctr, P>,
b: &ScanlineElement<T, Ctr, P>
) -> Orderingwhere
T: CoordinateType + Debug,Expand description
Helper function to be used as comparator for the SplayScanLine.
fn compare_scanline_elements<T, Ctr, P>(
a: &ScanlineElement<T, Ctr, P>,
b: &ScanlineElement<T, Ctr, P>
) -> Orderingwhere
T: CoordinateType + Debug,Helper function to be used as comparator for the SplayScanLine.