struct ScanlineElement<T, Ctr, P>(Rc<SweepEvent<T, Ctr, P>>)
where
T: CoordinateType;Expand description
Wrap a SweepEvent in order to use another implementation of Ord which is needed for the scanline.
Tuple Fields
0: Rc<SweepEvent<T, Ctr, P>>Trait Implementations
sourceimpl<T, Ctr: Clone, P: Clone> Clone for ScanlineElement<T, Ctr, P>where
T: CoordinateType + Clone,
impl<T, Ctr: Clone, P: Clone> Clone for ScanlineElement<T, Ctr, P>where T: CoordinateType + Clone,
sourcefn clone(&self) -> ScanlineElement<T, Ctr, P>
fn clone(&self) -> ScanlineElement<T, Ctr, P>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<T, Ctr, P> Deref for ScanlineElement<T, Ctr, P>where
T: CoordinateType,
impl<T, Ctr, P> Deref for ScanlineElement<T, Ctr, P>where T: CoordinateType,
sourceimpl<T, Ctr, P> Ord for ScanlineElement<T, Ctr, P>where
T: CoordinateType + Debug,
impl<T, Ctr, P> Ord for ScanlineElement<T, Ctr, P>where T: CoordinateType + Debug,
sourceimpl<T: PartialEq + CoordinateType, Ctr, P> PartialEq<ScanlineElement<T, Ctr, P>> for ScanlineElement<T, Ctr, P>
impl<T: PartialEq + CoordinateType, Ctr, P> PartialEq<ScanlineElement<T, Ctr, P>> for ScanlineElement<T, Ctr, P>
sourceimpl<T, Ctr, P> PartialOrd<ScanlineElement<T, Ctr, P>> for ScanlineElement<T, Ctr, P>where
T: CoordinateType + Debug,
impl<T, Ctr, P> PartialOrd<ScanlineElement<T, Ctr, P>> for ScanlineElement<T, Ctr, P>where T: CoordinateType + Debug,
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read more