fn divide_segment<T, Ctr, Property>(
    event: &Rc<SweepEvent<T, Ctr, Property>>,
    inter: Point<T>,
    queue: &mut BinaryHeap<Rc<SweepEvent<T, Ctr, Property>>>
)where
    T: CoordinateType + Debug,
    Ctr: Default,
    Property: Clone,
Split a segment into two segments at the intersection point inter and push the new events into the queue.