pub fn possible_intersection<F, I, Ctr, P>(
    edge_intersection_fn: I,
    event1: &Rc<SweepEvent<F, Ctr, P>>,
    event2: &Rc<SweepEvent<F, Ctr, P>>,
    queue: &mut BinaryHeap<Rc<SweepEvent<F, Ctr, P>>>
) -> boolwhere
    F: CoordinateType + Debug,
    I: Fn(&Edge<F>, &Edge<F>) -> EdgeIntersection<F, F, Edge<F>>,
    Ctr: Default,
    P: Clone,
Check two neighboring events for intersection and make necessary modifications to them and the queue.

event1 must appear before event2 in the scan line.

Returns: true if there was an intersection and modification to the queue.