Function iron_shapes_booleanop::connect_edges::filter_events
source · fn filter_events<T, Ctr, P, ContributesToResultFn>(
sorted_events: &[Rc<SweepEvent<T, Ctr, P>>],
contributes_to_result: ContributesToResultFn
) -> Vec<Rc<SweepEvent<T, Ctr, P>>>where
T: CoordinateType + Debug,
ContributesToResultFn: Fn(&SweepEvent<T, Ctr, P>) -> bool,Expand description
Take all the events that contribute to the result.
This depends on the boolean operation to be performed.
Also adjusts the prev pointers for hole attribution.