Function iron_shapes_booleanop::connect_edges::next_index
source · fn next_index<T: CoordinateType>(
events: &[Event<T>],
start_index: usize,
used: &[bool]
) -> Option<usize>Expand description
Given an index of an event get the index of another event with the same coordinates that is not yet marked as used.