pub enum PolygonSemantics {
Union,
XOR,
}Expand description
Define the ‘inside’ of a polygon. Significant for self-overlapping polygons.
Union: A pointpis inside the polygon if the winding number is larger than0. This means that if a polygon overlaps with itself or multiple polygons overlap, the overlapping area is always ‘inside’.XOR: A pointpis inside the polygon if the winding number modulo 2 is larger than0. This means that if an odd number of polygons overlap, the overlapping area is ‘inside’ the polygon. In case of an even number of overlaps, the overlapping area is ‘outside’.
This plays an important role for self-overlapping polygons and self-overlapping multi-polygons.
Variants
Union
A point p is inside the polygon if the winding number is larger than 0.
XOR
A point p is inside the polygon if the winding number modulo 2 is larger than 0.