Struct iron_shapes_booleanop::sweep_line::sweep_event::MutablePart
source · struct MutablePart<T, Ctr, Property> {
other_event: Weak<SweepEvent<T, Ctr, Property>>,
prev: Weak<SweepEvent<T, Ctr, Property>>,
counter: Ctr,
pos: usize,
}Expand description
Mutable data of a sweep event.
Fields
other_event: Weak<SweepEvent<T, Ctr, Property>>Reference to the event associated with the other endpoint of the edge.
prev: Weak<SweepEvent<T, Ctr, Property>>Edge below this event. This is used to find polygon-hole relationships.
counter: Ctrpos: usizeIndex of this event in an array. In a later step of the algorithm this will hold the index of the other event.